# [Zope-tests] OK : Zope 3.4 Known Good Set / py2.5-32bit-linux

buildbot at pov.lt buildbot at pov.lt
Wed Feb 2 23:01:14 EST 2011

- Previous message: [Zope-tests] FAILED : winbot / z3c.rml_py_265_32
- Next message: [Zope-tests] OK : Zope Buildbot / zope2.12-py2.6 slave-ubuntu64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope 3.4 Known Good Set / py2.5-32bit-linux
    Build: https://zope3.pov.lt/buildbot/builders/py2.5-32bit-linux/builds/926

    Build Reason: The Nightly scheduler named 'nightly2' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: https://zope3.pov.lt/buildbot/

- Previous message: [Zope-tests] FAILED : winbot / z3c.rml_py_265_32
- Next message: [Zope-tests] OK : Zope Buildbot / zope2.12-py2.6 slave-ubuntu64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list